@@ -17,6 +17,7 @@
  */
 #include "thememetadata.h"
 
+#include <QFile>
 #include <QSharedData>
 #include <QSharedPointer>
 
@@ -40,6 +41,7 @@ public:
     QString copyright;
     QString path;
     QString configfile;
+    bool supportsBackground;
 };
 
 ThemeMetadata::ThemeMetadata(const QString &id, const QString &path)
@@ -55,12 +57,13 @@ ThemeMetadata::ThemeMetadata(const ThemeMetadata &other)
 {
 }
 
-ThemeMetadata& ThemeMetadata::operator=( const ThemeMetadata &other )
+ThemeMetadata &ThemeMetadata::operator=(const ThemeMetadata &other)
 {
-  if ( this != &other )
-    d = other.d;
+    if (this != &other) {
+        d = other.d;
+    }
 
-  return *this;
+    return *this;
 }
 
 ThemeMetadata::~ThemeMetadata()
@@ -77,7 +80,7 @@ void ThemeMetadata::read(const QString &filename)
 
     KConfigGroup config = configFile->group("SddmGreeterTheme");
 
-    //d->themeid = config.readEntry("Theme-Id");
+    // d->themeid = config.readEntry("Theme-Id");
     d->name = config.readEntry("Name");
     d->description = config.readEntry("Description");
     d->author = config.readEntry("Author");
@@ -90,6 +93,8 @@ void ThemeMetadata::read(const QString &filename)
     d->screenshot = config.readEntry("Screenshot");
     d->copyright = config.readEntry("Copyright");
     d->configfile = config.readEntry("ConfigFile");
+
+    d->supportsBackground = QFile::exists(d->path + d->configfile);
 }
 
 QString ThemeMetadata::path() const
@@ -161,3 +166,8 @@ QString ThemeMetadata::configfile() const
 {
     return d->configfile;
 }
+
+bool ThemeMetadata::supportsBackground() const
+{
+    return d->supportsBackground;
+}
